@@ -1,3 +1,4 @@
+"""Module provider for luadns"""
 from __future__ import absolute_import
 import json
 import logging
@@ -11,7 +12,8 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['luadns.com']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for luadns"""
     subparser.add_argument(
         "--auth-username", help="specify email address for authentication")
     subparser.add_argument(
@@ -19,14 +21,13 @@ def ProviderParser(subparser):
 
 
 class Provider(BaseProvider):
-
+    """Provider class for luadns"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
         self.api_endpoint = 'https://api.luadns.com/v1'
 
-    def authenticate(self):
-
+    def _authenticate(self):
         payload = self._get('/zones')
 
         domain_info = next(
@@ -39,14 +40,17 @@ class Provider(BaseProvider):
 
     # Create record. If record already exists with the same content, do nothing'
 
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         # check if record already exists
-        existing_records = self.list_records(type, name, content)
+        existing_records = self._list_records(rtype, name, content)
         if len(existing_records) == 1:
             return True
 
-        payload = self._post('/zones/{0}/records'.format(self.domain_id), {'type': type,
-                                                                           'name': self._fqdn_name(name), 'content': content, 'ttl': self._get_lexicon_option('ttl')})
+        self._post('/zones/{0}/records'.format(self.domain_id),
+                   {'type': rtype,
+                    'name': self._fqdn_name(name),
+                    'content': content,
+                    'ttl': self._get_lexicon_option('ttl')})
 
         LOGGER.debug('create_record: %s', True)
         return True
@@ -54,7 +58,7 @@ class Provider(BaseProvider):
     # List all records. Return an empty list if no records found
     # type, name and content are used to filter records.
     # If possible filter during the query, otherwise filter after response is received.
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         payload = self._get('/zones/{0}/records'.format(self.domain_id))
 
         records = []
@@ -68,8 +72,8 @@ class Provider(BaseProvider):
             }
             records.append(processed_record)
 
-        if type:
-            records = [record for record in records if record['type'] == type]
+        if rtype:
+            records = [record for record in records if record['type'] == rtype]
         if name:
             records = [record for record in records if record['name']
                        == self._full_name(name)]
@@ -81,19 +85,19 @@ class Provider(BaseProvider):
         return records
 
     # Create or update a record.
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
 
         data = {
             'ttl': self._get_lexicon_option('ttl')
         }
-        if type:
-            data['type'] = type
+        if rtype:
+            data['type'] = rtype
         if name:
             data['name'] = self._fqdn_name(name)
         if content:
             data['content'] = content
 
-        payload = self._put(
+        self._put(
             '/zones/{0}/records/{1}'.format(self.domain_id, identifier), data)
 
         LOGGER.debug('update_record: %s', True)
@@ -101,10 +105,10 @@ class Provider(BaseProvider):
 
     # Delete an existing record.
     # If record does not exist, do nothing.
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -112,27 +116,26 @@ class Provider(BaseProvider):
         LOGGER.debug('delete_records: %s', delete_record_id)
 
         for record_id in delete_record_id:
-            payload = self._delete(
+            self._delete(
                 '/zones/{0}/records/{1}'.format(self.domain_id, record_id))
 
         LOGGER.debug('delete_record: %s', True)
         return True
 
     # Helpers
-
-    def _request(self, action='GET',  url='/', data=None, query_params=None):
+    def _request(self, action='GET', url='/', data=None, query_params=None):
         if data is None:
             data = {}
         if query_params is None:
             query_params = {}
-        r = requests.request(action, self.api_endpoint + url, params=query_params,
-                             data=json.dumps(data),
-                             auth=requests.auth.HTTPBasicAuth(self._get_provider_option(
-                                 'auth_username'), self._get_provider_option('auth_token')),
-                             headers={
-                                 'Content-Type': 'application/json',
-                                 'Accept': 'application/json'
-                             })
+        response = requests.request(action, self.api_endpoint + url, params=query_params,
+                                    data=json.dumps(data),
+                                    auth=requests.auth.HTTPBasicAuth(self._get_provider_option(
+                                        'auth_username'), self._get_provider_option('auth_token')),
+                                    headers={
+                                        'Content-Type': 'application/json',
+                                        'Accept': 'application/json'
+                                    })
         # if the request fails for any reason, throw an error.
-        r.raise_for_status()
-        return r.json()
+        response.raise_for_status()
+        return response.json()
